@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Number::Tolerant;
 # ABSTRACT: tolerance ranges for inexact numbers
-$Number::Tolerant::VERSION = '1.705';
+$Number::Tolerant::VERSION = '1.706';
 use Sub::Exporter::Util;
 use Sub::Exporter 0.950 -setup => {
   exports => { tolerance => Sub::Exporter::Util::curry_class('new'), },
@@ -525,7 +525,7 @@ Number::Tolerant - tolerance ranges for inexact numbers
 
 =head1 VERSION
 
-version 1.705
+version 1.706
 
 =head1 SYNOPSIS
 
@@ -795,6 +795,30 @@ also provided the initial implementation for the offset type.
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Alexandre Mestiashvili Karen Etheridge Ricardo SIGNES Smylers
+
+=over 4
+
+=item *
+
+Alexandre Mestiashvili <alex@biotec.tu-dresden.de>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Ricardo SIGNES <rjbs@codesimply.com>
+
+=item *
+
+Smylers <Smylers@stripey.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2004 by Ricardo Signes.
